pub struct InvocationControl { /* private fields */ }Expand description
Adapter-supplied cancellation and timeout signals for one invocation.
A timeout is represented as a future so native, Cloudflare, tests, and other adapters can use their own clock/runtime without leaking it into the operation graph.
Implementations
Sourceimpl InvocationControl
impl InvocationControl
pub const fn new() -> Self
pub fn with_cancellation(self, token: CancellationToken) -> Self
pub fn with_timeout<Timeout>(self, timeout: Timeout) -> Self